pub struct ToolError {
pub kind: ToolErrorKind,
pub message: String,
pub retry_safety: RetrySafety,
pub metadata: BTreeMap<String, Value>,
}Expand description
Structured tool execution error.
Fields
kind: ToolErrorKindNormalized category.
message: StringSafe human-readable explanation.
retry_safety: RetrySafetyRetry-safety classification.
metadata: BTreeMap<String, Value>Namespaced diagnostic metadata.
Implementations
Sourceimpl ToolError
impl ToolError
Sourcepub const fn diagnostic_code(&self) -> &'static str
pub const fn diagnostic_code(&self) -> &'static str
Returns a stable diagnostic identifier without exposing error payloads.
Resolve causes and corrective actions with runifold ai explain <code>.
This does not change the error’s retry safety, Display or serialization.
Sourcepub fn local(kind: ToolErrorKind, message: impl Into<String>) -> Self
pub fn local(kind: ToolErrorKind, message: impl Into<String>) -> Self
Creates a local tool error with unknown retry safety.