IntoToolError

Trait IntoToolError 

pub trait IntoToolError {
    // Required method
    fn into_tool_error(self) -> ToolError;
}
Explicit conversion from an application error into a safe Tool failure.

Implementations decide which message is safe for model and operator visibility, as well as the normalized kind and retry-safety classification.

Required Methods

fn into_tool_error(self) -> ToolError

Converts this application failure into the canonical Tool error.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors